@@ -31,10 +31,12 @@
 
 Sweeper::Sweeper(bool automatic)
    : KXmlGuiWindow(nullptr)
+   , generalCLI(new QTreeWidgetItem(QStringList(i18nc("General system content", "General"))))
+   , webbrowsingCLI(new QTreeWidgetItem(QStringList(i18nc("Web browsing content", "Web Browsing"))))
    , m_privacyConfGroup(KSharedConfig::openConfig(QStringLiteral("kprivacyrc"), KConfig::NoGlobals), "Cleaning")
    , m_automatic(automatic)
 {
-   QWidget *mainWidget = new QWidget(this);
+   auto mainWidget = new QWidget(this);
    ui.setupUi(mainWidget);
    setCentralWidget(mainWidget);
 
@@ -46,9 +48,7 @@ Sweeper::Sweeper(bool automatic)
 
    setAutoSaveSettings();
 
-   generalCLI     = new QTreeWidgetItem(QStringList() << i18nc("General system content", "General"));
    sw->addTopLevelItem(generalCLI);
-   webbrowsingCLI = new QTreeWidgetItem(QStringList() << i18nc("Web browsing content", "Web Browsing"));
    sw->addTopLevelItem(webbrowsingCLI);
 
    generalCLI->setExpanded(true);
@@ -81,19 +81,15 @@ Sweeper::~Sweeper()
 
 void Sweeper::load()
 {
-   QLinkedList<PrivacyAction*>::iterator itr;
-
-   for (itr = checklist.begin(); itr != checklist.end(); ++itr) {
-      (*itr)->setCheckState(0, m_privacyConfGroup.readEntry((*itr)->configKey(), true) ? Qt::Checked : Qt::Unchecked);
+   for (auto &&act: checklist) {
+      act->setCheckState(0, m_privacyConfGroup.readEntry(act->configKey(), true) ? Qt::Checked : Qt::Unchecked);
    }
 }
 
 void Sweeper::save()
 {
-   QLinkedList<PrivacyAction*>::iterator itr;
-
-   for (itr = checklist.begin(); itr != checklist.end(); ++itr) {
-      m_privacyConfGroup.writeEntry((*itr)->configKey(), (*itr)->checkState(0) == Qt::Checked);
+   for (auto &&act: checklist) {
+      m_privacyConfGroup.writeEntry(act->configKey(), act->checkState(0) == Qt::Checked);
    }
 
    m_privacyConfGroup.sync();
@@ -101,25 +97,18 @@ void Sweeper::save()
 
 void Sweeper::selectAll()
 {
-   QLinkedList<PrivacyAction*>::iterator itr;
-
-   for (itr = checklist.begin(); itr != checklist.end(); ++itr) {
-      (*itr)->setCheckState(0, Qt::Checked);
+   for (auto &&act: checklist) {
+      act->setCheckState(0, Qt::Checked);
    }
-
 }
 
 void Sweeper::selectNone()
 {
-   QLinkedList<PrivacyAction*>::iterator itr;
-
-   for (itr = checklist.begin(); itr != checklist.end(); ++itr) {
-      (*itr)->setCheckState(0, Qt::Unchecked);
+   for (auto &&act: checklist) {
+      act->setCheckState(0, Qt::Unchecked);
    }
-
 }
 
-
 void Sweeper::cleanup()
 {
    if (!m_automatic) {
@@ -131,16 +120,14 @@ void Sweeper::cleanup()
    ui.statusTextEdit->clear();
    ui.statusTextEdit->setText(i18n("Starting cleanup..."));
 
-   QLinkedList<PrivacyAction*>::iterator itr;
-
-   for (itr = checklist.begin(); itr != checklist.end(); ++itr) {
-      if((*itr)->checkState(0) == Qt::Checked) {
-         QString statusText = i18n("Clearing %1...", (*itr)->text(0));
+   for (auto &&act: checklist) {
+      if(act->checkState(0) == Qt::Checked) {
+         QString statusText = i18n("Clearing %1...", act->text(0));
          ui.statusTextEdit->append(statusText);
 
          // actions return whether they were successful
-         if(!(*itr)->action()) {
-            QString errorText =  i18n("Clearing of %1 failed: %2", (*itr)->text(0), (*itr)->getErrMsg());
+         if(!act->action()) {
+            QString errorText = i18n("Clearing of %1 failed: %2", act->text(0), act->getErrMsg());
             ui.statusTextEdit->append(errorText);
          }
       }
